pub struct Pattern<U: Universe, PNode, PEdge: Eq + Hash> { /* private fields */ }

Implementations

source

impl<U: Universe> Pattern<U, (), (PortOffset, PortOffset)>

source

impl<U: Universe, PNode: NodeProperty, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>

source

pub fn new() -> Self

source

pub fn require(&mut self, node: U, property: PNode)

source

pub fn add_edge(&mut self, u: U, v: U, property: PEdge)

source

pub fn root(&self) -> Option<U>

source

pub fn set_root(&mut self, root: U)

source

pub fn dot_string(&self) -> Stringwhere U: Debug, PNode: Debug, PEdge: Debug,

source

pub fn set_any_root(&mut self) -> Result<U, NoRootFound>where U: Ord,

Let the pattern fix a root

We require Ord so that this is deterministic (do not rely on hash)

source

pub fn edges(&self) -> Option<Vec<Edge<U, PNode, PEdge>>>

The edges of the pattern, in a connected order (if it exists)

This will clone node and edge properties as edge properties might need to be reversed.

If no root was set, this returns None.

source

impl Pattern<NodeIndex, (), (PortOffset, PortOffset)>

source

pub fn from_portgraph<G>(g: G) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,

source

pub fn from_rooted_portgraph<G>(g: G, root: NodeIndex) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,

source

impl<W: NodeProperty> Pattern<NodeIndex, W, (PortOffset, PortOffset)>

source

pub fn from_weighted_portgraph<G>( g: G, w: impl SecondaryMap<NodeIndex, W> ) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,

source

impl<U: Universe, PNode, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>

source

pub fn try_into_line_pattern<F: for<'a> Fn(&'a PEdge, &'a PEdge) -> bool>( self, valid_successor: F ) -> Option<LinePattern<U, PNode, PEdge>>

Try to convert the pattern into a line pattern

Attempt every possible root and return None if none worked.