Struct portmatching::patterns::Pattern
source · pub struct Pattern<U: Universe, PNode, PEdge: Eq + Hash> { /* private fields */ }Implementations
sourceimpl<U: Universe> Pattern<U, (), (PortOffset, PortOffset)>
impl<U: Universe> Pattern<U, (), (PortOffset, PortOffset)>
pub fn into_single_pattern_matcher( self ) -> SinglePatternMatcher<U, (), (PortOffset, PortOffset)>
sourceimpl<U: Universe, PNode: NodeProperty, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>
impl<U: Universe, PNode: NodeProperty, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>
pub fn new() -> Self
pub fn require(&mut self, node: U, property: PNode)
pub fn add_edge(&mut self, u: U, v: U, property: PEdge)
pub fn root(&self) -> Option<U>
pub fn set_root(&mut self, root: U)
pub fn dot_string(&self) -> Stringwhere U: Debug, PNode: Debug, PEdge: Debug,
sourcepub fn set_any_root(&mut self) -> Result<U, NoRootFound>where
U: Ord,
pub fn set_any_root(&mut self) -> Result<U, NoRootFound>where U: Ord,
Let the pattern fix a root
We require Ord so that this is deterministic (do not rely on hash)
sourceimpl Pattern<NodeIndex, (), (PortOffset, PortOffset)>
impl Pattern<NodeIndex, (), (PortOffset, PortOffset)>
pub fn from_portgraph<G>(g: G) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,
pub fn from_rooted_portgraph<G>(g: G, root: NodeIndex) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,
sourceimpl<W: NodeProperty> Pattern<NodeIndex, W, (PortOffset, PortOffset)>
impl<W: NodeProperty> Pattern<NodeIndex, W, (PortOffset, PortOffset)>
pub fn from_weighted_portgraph<G>( g: G, w: impl SecondaryMap<NodeIndex, W> ) -> Selfwhere G: LinkView + IntoNodeIdentifiers + GraphBase<NodeId = NodeIndex>,
sourceimpl<U: Universe, PNode, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>
impl<U: Universe, PNode, PEdge: EdgeProperty> Pattern<U, PNode, PEdge>
sourcepub fn try_into_line_pattern<F: for<'a> Fn(&'a PEdge, &'a PEdge) -> bool>(
self,
valid_successor: F
) -> Option<LinePattern<U, PNode, PEdge>>
pub fn try_into_line_pattern<F: for<'a> Fn(&'a PEdge, &'a PEdge) -> bool>( self, valid_successor: F ) -> Option<LinePattern<U, PNode, PEdge>>
Try to convert the pattern into a line pattern
Attempt every possible root and return None if none worked.